===============
Release History
===============

0.1 (Released 2019-03-21)
-------------------------

* Support for reading ARM datasets that are timeseries, either 1D or 2D
* Ability to download data from ARM datastreams
* Ability to make multipanel timeseries plots

